( cd usr/bin ; rm -rf als )
( cd usr/bin ; ln -sf atool als )
( cd usr/bin ; rm -rf acat )
( cd usr/bin ; ln -sf atool acat )
( cd usr/bin ; rm -rf adiff )
( cd usr/bin ; ln -sf atool adiff )
( cd usr/bin ; rm -rf apack )
( cd usr/bin ; ln -sf atool apack )
( cd usr/bin ; rm -rf arepack )
( cd usr/bin ; ln -sf atool arepack )
( cd usr/bin ; rm -rf aunpack )
( cd usr/bin ; ln -sf atool aunpack )
( cd usr/man/man1 ; rm -rf als.1 )
( cd usr/man/man1 ; ln -sf atool.1 als.1 )
( cd usr/man/man1 ; rm -rf acat.1 )
( cd usr/man/man1 ; ln -sf atool.1 acat.1 )
( cd usr/man/man1 ; rm -rf adiff.1 )
( cd usr/man/man1 ; ln -sf atool.1 adiff.1 )
( cd usr/man/man1 ; rm -rf apack.1 )
( cd usr/man/man1 ; ln -sf atool.1 apack.1 )
( cd usr/man/man1 ; rm -rf arepack.1 )
( cd usr/man/man1 ; ln -sf atool.1 arepack.1 )
( cd usr/man/man1 ; rm -rf aunpack.1 )
( cd usr/man/man1 ; ln -sf atool.1 aunpack.1 )
